@@ -62,6 +62,7 @@ SKIN_TEXT = {
     'sch-resume_post'    : TT('Resume post-processing'), #:  #: Config->Scheduler
     'sch-scan_folder'    : TT('Scan watched folder'), #:  #: Config->Scheduler
     'sch-rss_scan'       : TT('Read RSS feeds'), #:  #: Config->Scheduler
+    'sch-remove_failed'  : TT('Remove failed jobs'), #: Config->Scheduler
 
 # General texts
     'default' : TT('Default'), #: Default value, used in dropdown menus
@@ -100,6 +101,16 @@ SKIN_TEXT = {
     'homePage' : TT('Home page'), #: Home page of the SABnzbd project
     'source' : TT('Source'), #: Where to find the SABnzbd sourcecode
     'or' : TT('or'), #: Used in "IRC or IRC-Webaccess"
+    'host' : TT('Host'),
+    'comment' : TT('Comment'),
+    'send' : TT('Send'),
+    'cancel' : TT('Cancel'),
+    'other' : TT('Other'),
+    'report' : TT('Report'),
+    'video' : TT('Video'),
+    'audio' : TT('Audio'),
+    'notUsed' : TT('Not used'),
+    'orLess' : TT('or less'),
 
 # General template elements
     'signOn' : TT('The automatic usenet download tool'), #: SABnzbd's theme line
@@ -231,7 +242,10 @@ SKIN_TEXT = {
     'purgeCompl' : TT('Purge Completed NZBs'), #: Button to delete all completed jobs in History
     'opt-extra-NZB' : TT('Optional Supplemental NZB'), #: Button to add NZB to failed job in History
     'msg-path' : TT('Path'), #: Path as displayed in History details
-
+    'spam' : TT('Virus/spam'),
+    'encrypted' : TT('Passworded'),
+    'expired' : TT('Out of retention'),
+    'otherProblem' : TT('Other problem'),
 
 # Connections page
     'link-forceDisc' : TT('Force Disconnect'), #: Status page button
@@ -270,6 +284,7 @@ SKIN_TEXT = {
     'version' : TT('Version'),
     'uptime' : TT('Uptime'),
     'backup' : TT('Backup'), #: Indicates that server is Backup server in Status page
+    'oznzb' : TT('OZnzb'),
 
 # Config->General
     'generalConfig' : TT('General configuration'),
@@ -298,6 +313,8 @@ SKIN_TEXT = {
     'explain-https_cert' : TT('File name or path to HTTPS Certificate.'),
     'opt-https_key' : TT('HTTPS Key'),
     'explain-https_key' : TT('File name or path to HTTPS Key.'),
+    'opt-https_chain' : TT('HTTPS Chain Certifcates'),
+    'explain-https_chain' : TT('File name or path to HTTPS Chain.'),
     'tuning' : TT('Tuning'),
     'opt-refresh_rate' : TT('Queue auto refresh interval:'),
     'explain-refresh_rate' : TT('Refresh interval of the queue web-interface page(sec, 0= none).'),
@@ -377,13 +394,18 @@ SKIN_TEXT = {
     'explain-top_only' : TT('Enable for less memory usage. Disable to prevent slow jobs from blocking the queue.'),
     'opt-safe_postproc' : TT('Post-Process Only Verified Jobs'),
     'explain-safe_postproc' : TT('Only perform post-processing on jobs that passed all PAR2 checks.'),
-    'opt-pause_on_pwrar' : TT('Pause job when encrypted RAR is downloaded'),
-    'explain-pause_on_pwrar' : TT('You\'ll need to set a password and resume the job.'),
+    'opt-pause_on_pwrar' : TT('Action when encrypted RAR is downloaded'),
+    'explain-pause_on_pwrar' : TT('In case of "Pause", you\'ll need to set a password and resume the job.'),
     'opt-no_dupes' : TT('Detect Duplicate Downloads'),
     'explain-no_dupes' : TT('Detect identically named NZB files (requires NZB backup option) and duplicate titles across RSS feeds.'),
+    'opt-action_on_unwanted_extensions' : TT('Action when unwanted extension detected'),
+    'explain-action_on_unwanted_extensions' : TT('Action when an unwanted extension is detected in RAR files'),
+    'opt-unwanted_extensions' : TT('Unwanted extensions'),
+    'explain-unwanted_extensions' : TT('List all unwanted extensions. For example: <b>exe</b> or <b>exe, com</b>'),
     'nodupes-off' : TT('Off'), #: Three way switch for duplicates
     'nodupes-ignore' : TT('Discard'), #: Three way switch for duplicates
     'nodupes-pause' : TT('Pause'), #: Three way switch for duplicates
+    'abort' : TT('Abort'), #: Three way switch for encrypted posts
     'opt-sfv_check' : TT('Enable SFV-based checks'),
     'explain-sfv_check' : TT('Do an extra verification based on SFV files.'),
     'opt-unpack_check' : TT('Check result of unpacking'),
@@ -415,6 +437,7 @@ SKIN_TEXT = {
     'explain-auto_sort' : TT('Automatically sort items by (average) age.'),
     'opt-check_new_rel' : TT('Check for New Release'),
     'explain-check_new_rel' : TT('Weekly check for new SABnzbd release.'),
+    'also-test' : TT('Also test releases'), #: Pick list for weekly test for new releases
     'opt-replace_spaces' : TT('Replace Spaces in Foldername'),
     'explain-replace_spaces' : TT('Replace spaces with underscores in folder names.'),
     'opt-replace_dots' : TT('Replace dots in Foldername'),
@@ -440,6 +463,7 @@ SKIN_TEXT = {
     'swtag-pp' : TT('Post processing'),
     'swtag-naming' : TT('Naming'),
     'swtag-quota' : TT('Quota'),
+    'swtag-indexing' : TT('Indexing'),
     'opt-quota_size' : TT('Size'), #: Size of the download quota
     'explain-quota_size' : TT('How much can be downloaded this month (K/M/G)'),
     'opt-quota_day' : TT('Reset day'), #: Reset day of the download quota
@@ -454,7 +478,27 @@ SKIN_TEXT = {
     'explain-max_art_tries' : TT('Maximum number of retries per server'),
     'opt-max_art_opt' : TT('Only for optional servers'),
     'explain-max_art_opt' : TT('Apply maximum retries only to optional servers'),
-
+    'opt-fail_hopeless' : TT('Abort jobs that cannot be completed'),
+    'explain-fail_hopeless' : TT('When during download it becomes clear that too much data is missing, abort the job'),
+    'opt-rating_enable' : TT('Enable OZnzb Integration'),
+    'explain-rating_enable' : TT('Enhanced functionality including ratings and extra status information is available when connected to OZnzb indexer.'),
+    'opt-rating_api_key' : TT('Site API Key'),
+    'explain-rating_api_key' : TT('This key provides identity to indexer. Refer to https://www.oznzb.com/profile.'),
+    'tip-rating_api_key' : TT('Refer to https://www.oznzb.com/profile'),
+    'opt-rating_feedback' : TT('Automatic Feedback'),
+    'explain-rating_feedback' : TT('Send automatically calculated validation results for downloads to indexer.'),
+    'opt-rating_filter_enable' : TT('Enable Filtering'),
+    'explain-rating_filter_enable' : TT('Action downloads according to filtering rules.'),
+    'opt-rating_filter_abort_if' : TT('Abort If'),
+    'opt-rating_filter_pause_if' : TT('Else Pause If'),
+    'opt-rating_filter_video' : TT('Video rating'),
+    'opt-rating_filter_audio' : TT('Audio rating'),
+    'opt-rating_filter_passworded' : TT('Passworded'),
+    'opt-rating_filter_spam' : TT('Spam'),
+    'opt-rating_filter_confirmed' : TT('Confirmed'),
+    'opt-rating_filter_downvoted' : TT('More thumbs down than up'),
+    'opt-rating_filter_keywords' : TT('Title keywords'),
+    'explain-rating_filter_keywords' : TT('Comma separated list'),
 
 # Config->Server
     'configServer' : TT('Server configuration'), #: Caption
@@ -550,6 +594,10 @@ SKIN_TEXT = {
     'explain-growl_password' : TT('Optional password for Growl server'), #: Don't translate "Growl"
     'opt-ntfosd_enable' : TT('Enable NotifyOSD'), #: Don't translate "NotifyOSD"
     'explain-ntfosd_enable' : TT('Send notifications to NotifyOSD'), #: Don't translate "NotifyOSD"
+    'opt-ncenter_enable' : TT('Notification Center'),
+    'explain-ncenter_enable' : TT('Send notifications to Notification Center'),
+    'opt-notify_classes' : TT('Notification classes'),
+    'explain-notify_classes' : TT('Enable classes of messages to be reported (none, one or multiple)'),
     'testNotify' : TT('Test Notification'),
 
 # Config->Newzbin
@@ -860,6 +908,7 @@ SKIN_TEXT = {
     'wizard-port-eg' : TT('E.g. 119 or 563 for SSL'), #: Wizard port number examples
     'wizard-exit' : TT('Exit SABnzbd'), #: Wizard EXIT button on first page
     'wizard-start' : TT('Start Wizard'), #: Wizard START button on first page
+    'wizard-create-account' : TT('If you do not have an account it can be created at '),
 
 #Special
     'yourRights' : TT('''
